@@ -486,7 +486,7 @@ def draw_errorbar_plot(k,scores,sd, add_title=None, kticks=None, yticks=None, fi
 
 	plt.figure()
 
-	plt.plot(k,scores,c='tab:blue',linewidth=2,linestyle='-',alpha=0.5)
+	plt.plot(k,scores,c='tab:blue',linewidth=2,linestyle='--',alpha=1)
 	plt.errorbar(k, scores, yerr=sd, fmt='o', markersize=5, marker='o',color='black',
 				markeredgecolor='gray', markeredgewidth=2,
 				ecolor='gray', elinewidth=1.5, capsize=5)
@@ -532,11 +532,42 @@ def compute_best_k(k,score,score_sd,mode='greatest',out='single'):
 	thold = score[k_argmin] + 2*score_sd[k_argmin]
 	k_set = set(k_arr[score - 2*score_sd <= thold])
 
+	# establish which of the candidate values is a local minimum
+	local_minima_bool = np.zeros(len(k)).astype(bool)
+	for k_idx, k_val in enumerate(k):
+
+		# compute local sd
+		if (k_idx == 0):
+			local_sd = np.max([score_sd[k_idx],score_sd[k_idx+1]])
+			comp_score = score[k_idx+1]
+		elif (k_idx == len(k)-1):
+			local_sd = np.max([score_sd[k_idx-1],score_sd[k_idx]])
+			comp_score = score[k_idx-1]
+		elif (k_idx > 0) and (k_idx < len(k)-1):
+			local_sd = np.max([score_sd[k_idx-1],score_sd[k_idx],score_sd[k_idx+1]])
+			comp_score = np.min([score[k_idx-1],score[k_idx+1]])
+
+		#local_sd = score_sd[k_idx]
+
+		# check if k_val is a local minimum 
+		upper_bound = score[k_idx]+2*local_sd
+		if (upper_bound <= comp_score):
+			local_minima_bool[k_idx] = True
+
+	# estimate k as the greatest local min
+	if np.any(local_minima_bool):
+		k_local_min = np.max(k_arr[local_minima_bool])
+	else:
+		k_local_min = max(k_set)
+		print('no local min, buddy :-(')
+
 	# determine whether to take the greatest or smallest candidate k
 	if (mode == 'greatest'):
 		k_estimate = max(k_set)
 	elif (mode == 'smallest'):
 		k_estimate = min(k_set)
+	elif (mode == 'local'):
+		k_estimate = k_local_min
 	else:
 		raise ValueError("invalid value for mode. Choose 'greatest' " + \
 						 "/'smallest' to use the" + \
@@ -574,7 +605,10 @@ def process_scores(k_list,scores,scores_sd,out,verbose=False, tabspace='',
 											mode='greatest', out='set')
 	elif (best_k_mode == 'smallest'):
 		k_estimate, k_set = compute_best_k(k_list,scores,scores_sd,
-											mode='greatest', out='set')
+											mode='smallest', out='set')
+	elif (best_k_mode == 'local'):
+		k_estimate, k_set = compute_best_k(k_list,scores,scores_sd,
+											mode='local', out='set')
 	else:
 		raise ValueError("invalid value for best_k_mode. Choose 'greatest' " +
 						 "or 'smallest' to estimate the number of clusters " + 
